<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'ボックスで表示',
	'affichage_documents_en_grand' => '大型表示',
	'affichage_documents_en_liste_compacte' => 'コンパクトリスト表示',
	'aucun_audio' => 'サウンドなし',
	'aucun_document' => 'ドキュメントなし',
	'aucun_file' => 'ドキュメントなし',
	'aucun_image' => '画像なし',
	'aucun_video' => '動画なし',
	'aucune_utilisation' => 'このドキュメントは使用されていません',
	'aucune_vignette' => 'サムネイルなし',

	// B
	'bouton_ajouter_document' => 'ドキュメントを追加する',
	'bouton_ajouter_image' => '画像を追加する',
	'bouton_ajouter_image_document' => '画像またはドキュメントを追加する',
	'bouton_attacher_document' => 'つなぐ',
	'bouton_copier_local' => 'サイトにコピーする',
	'bouton_download_depuis' => '　',
	'bouton_download_local' => '自分のコンピュータより',
	'bouton_download_par_ftp' => 'ザーバーより',
	'bouton_download_par_mediatheque' => 'メディアライブラリより',
	'bouton_download_sur_le_web' => 'インターネットより',
	'bouton_enlever_document' => '引き離す',
	'bouton_enlever_supprimer_document' => '取り除く',
	'bouton_enlever_supprimer_document_confirmation' => 'ドキュメントを取り除いてよろしいですか？',
	'bouton_modifier_document' => '修正する',
	'bouton_parcourir' => 'ブラウズ…',
	'bouton_refresh_document' => 'ドキュメントを更新',
	'bouton_remplacer_document' => 'ドキュメントを置き換える',
	'bouton_remplacer_image' => '画像を置き換える',
	'bouton_remplacer_image_document' => '画像またはドキュメントを置き換える',
	'bouton_supprimer' => '取り除く',
	'bouton_supprimer_tous_orphelins' => '引き離されたドキュメントを削除する', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => '引き離されたドキュメントを@nb@つ削除してよろしいですか？', # MODIF
	'bouton_upload' => 'アップロードする',

	// D
	'des_audios' => 'サウンドトラック@nb@本',
	'des_documents' => 'ドキュメント@nb@件',
	'des_files' => 'ドキュメント@nb@件',
	'des_images' => '画像@nb@枚',
	'des_utilisations' => '使用は@nb@回',
	'des_videos' => '動画@nb@本',
	'descriptif' => '記述', # MODIF
	'details_document' => '詳細',
	'details_document_afficher_masquer' => 'ドキュメントの詳細を表示／非表示',
	'document_attache_succes' => 'ドキュメントが追加されています',
	'document_copie_locale_succes' => 'ファイルがサイトにコピーされています',
	'document_installe_succes' => 'ファイルがロードされています',
	'document_vu' => '文書に挿入されています',
	'documents' => 'ライブラリ',
	'documents_brises' => '壊れています',
	'documents_distants' => 'リモート',
	'documents_locaux' => 'ローカル',
	'documents_non_publies' => '公開されていません',
	'documents_orphelins' => '未使用です',
	'documents_publies' => '公開されています',
	'documents_tous' => '全て',
	'double_clic_inserer_doc' => 'ダブルクリックして文章にこのショートカットを挿入',

	// E
	'entree_dimensions' => 'サイズ：',
	'entree_titre_document' => 'ドキュメントの題名：',
	'entree_titre_image' => '画像の題名：',
	'erreur_aucun_document' => 'このドキュメントはメディアライブラリにありません',
	'erreur_aucun_fichier' => 'ファイルが見つかりません',
	'erreur_autorisation' => 'アクセスが出来ません',
	'erreur_chemin_distant' => 'リモートファイル@nom@が見つかりませんでした',
	'erreur_chemin_ftp' => 'ファイルがサーバーには見つかりません',
	'erreur_copie_fichier' => '@nom@ファイルのコピーが出来ません',
	'erreur_deplacement_impossible' => '移動が出来ません',
	'erreur_dossier_tmp_manquant' => '一時フォルダが見つからないため、ファイルをダウンロードすることが出来ません',
	'erreur_ecriture_fichier' => 'ディスクへのファイルの書き込みエラー',
	'erreur_format_fichier_image' => '@nom@の形式は画像には適していません',
	'erreur_indiquez_un_fichier' => 'ファイルを指定してください。',
	'erreur_insertion_document_base' => '@fichier@ドキュメントがデータベースに保存出来ません',
	'erreur_objet_absent' => '不完全な情報を受信しました。',
	'erreur_suppression_vignette' => 'サムネイル削除エラー',
	'erreur_upload_type_interdit' => 'タイプ@nom@のファイルのダウンロードは不可です。',
	'erreur_upload_vignette' => 'サムネイル@nom@の読み込みエラー',
	'erreurs' => 'エラー@nb@',
	'erreurs_voir' => '@nb@エラーを表示する',

	// F
	'fichier_distant' => 'リモートファイル',
	'fichier_manquant' => 'ファイルが見つかりません',
	'fichier_modifie' => 'ファイルが変更されて保存をクリックしてください',
	'format_date_incorrect' => '日付または時刻が不正です。',

	// I
	'icone_creer_document' => 'ドキュメントを追加する',
	'id' => 'ID',
	'image_tourner_180' => '180°回転',
	'image_tourner_droite' => '右に90°回転',
	'image_tourner_gauche' => '左に90°回転',
	'info_dimensions_image' => 'サイズ：',
	'info_doc_max_poids' => 'ドキュメントは@maxi@未満にする必要があります（このファイルは@actuel@）',
	'info_document' => 'ドキュメント',
	'info_document_indisponible' => 'このドキュメントは使用出来ません',
	'info_documents' => 'ドキュメント',
	'info_duree' => '期間',
	'info_gauche_numero_document' => 'ドキュメント番号',
	'info_hauteur' => '高さ',
	'info_heure' => '時間',
	'info_illustrations' => 'イラスト',
	'info_image_max_poids' => 'ロゴは@maxi@未満にする必要があります（このファイルは@actuel@）',
	'info_image_max_taille' => '画像は@maxi@より小さくなければなりません。（このファイルは@actuel@です）',
	'info_inclusion_directe' => '直接インクルード:',
	'info_inclusion_vignette' => '含まれるビネット(半身写真、模様など):',
	'info_installer_tous_documents' => 'すべてのドキュメントをインストール',
	'info_largeur' => '幅',
	'info_logo_max_taille' => 'ロゴは、@maxi@より少ないべきです（このファイルは@actuel@）。',
	'info_mode' => 'テキストモード編集',
	'info_modifier_document' => 'ドキュメントの編集',
	'info_portfolio' => '写真集',
	'info_referencer_doc_distant' => 'インターネット上のドキュメントを参照：',
	'info_resolution_image' => '解像度',
	'info_resolution_mpx' => '@resolution@メガピクセル',
	'info_sans_vignette' => 'サムネイルなし',
	'info_statut_document' => 'このドキュメントは：',
	'info_taille' => 'サイズ',
	'info_telecharger' => '自分のコンピュータよりダウンロード：',
	'info_utilisation' => '使用',
	'infos' => '技術情報',
	'item_autoriser_selectionner_date_en_ligne' => '各ドキュメントの日付を変更出来るようにする',
	'item_non_autoriser_selectionner_date_en_ligne' => 'ドキュメントの日付は、サイト上に追加の日付にする',

	// L
	'label_activer_document_objets' => 'コンテンツのアプロードを有効にする',
	'label_apercu' => '概要',
	'label_caracteristiques' => '特性',
	'label_credits' => 'クレジット',
	'label_fichier' => 'ファイル',
	'label_fichier_vignette' => 'サムネイル',
	'label_paginer_par' => 'ソート',
	'label_parents' => 'このドキュメントは、次のアイテムに繋がれています。',
	'label_refdoc_joindre' => 'ドキュメント番号',
	'lien_tout_desordonner' => 'ソートをリセット',
	'lien_tout_desordonner_verif' => 'ドキュメントのソートは、リセットしてもよろしいですか',
	'lien_tout_enlever' => 'すべて削除', # MODIF
	'logo' => 'ロゴ',

	// M
	'media_audio' => 'サウンドトラック',
	'media_file' => 'その他',
	'media_image' => '画像',
	'media_video' => '動画',
	'miniature_automatique_active' => 'SPIPは自動的に画像のサムネイルを生成します',

	// N
	'nb_documents_attache_succes' => 'ドキュメントが@nb@つ追加された',
	'nb_documents_installe_succes' => 'ファイルが@nb@つ正常に読み込まれた',

	// O
	'objet_document' => 'ドキュメント',
	'objet_documents' => 'ドキュメント',
	'ordonner_ce_document' => 'このドキュメントを整理する',

	// P
	'par_date' => '日付',
	'par_hauteur' => '高さ',
	'par_id' => 'ID',
	'par_largeur' => '幅',
	'par_taille' => 'サイズ',
	'par_titre' => '題名',

	// T
	'texte_documents_joints' => '記事、セックションなどへ、アイテムの追加インターフェイスを有効にできます。こ
れらのファイルはテキストで参照することも、別々に表示することもできます。',
	'texte_documents_joints_2' => 'この設定は、記事へ画像などを挿入することに阻まれません',
	'titre_documents_joints' => '添付書類',
	'titre_page_documents_edit' => '@titre@ドキュメントの編集',
	'tous_les_medias' => 'すべてのメディア',
	'tout_dossier_upload' => '@upload@フォルダー全体',
	'tout_voir' => 'すべて見る',

	// U
	'un_audio' => 'サウンドトラック１本',
	'un_document' => 'ファイル 1 件',
	'un_file' => 'ドキュメント１件',
	'un_image' => '画像１枚',
	'un_video' => '動画１本',
	'une_utilisation' => '使用１つ',
	'upload_fichier_zip' => 'ZIPファイル',
	'upload_fichier_zip_texte' => 'インストールすることを提案しているファイルはZipファイルです。',
	'upload_fichier_zip_texte2' => 'このファイルは',
	'upload_info_mode_document' => '写真集に入れる',
	'upload_info_mode_image' => '写真集より取り除く',
	'upload_limit' => 'このファイルはサーバーにとって大きすぎます。 許可された<em>アップロード</em>
の最大サイズは、@max@です。',
	'upload_zip_conserver' => '解凍後にアーカイブを保存する',
	'upload_zip_decompacter' => '解凍して、ファイルをそれぞれ別で登録する。登録されるファイル群は下の通り。:',
	'upload_zip_mode_document' => '写真集にすべての画像を入れる',
	'upload_zip_telquel' => 'ZIPファイルとしてそのままインストールされます',
	'upload_zip_titrer' => 'ファイル名をそのまま使って、題名にする',

	// V
	'verifier_documents_brises' => '見つからないファイルを確認',
	'verifier_documents_inutilises' => 'ドキュメントへのリンクの確認',
	'vignette_supprimee' => 'サムネイルが取り除かれた',
];
